stage1_2/stage1_2.hh
changeset 934 2a42a68f4b59
parent 924 9e824bb0c3d4
child 946 c012a64dc2fa
--- a/stage1_2/stage1_2.hh	Sun Sep 28 16:35:44 2014 +0100
+++ b/stage1_2/stage1_2.hh	Sun Sep 28 17:39:28 2014 +0100
@@ -57,12 +57,12 @@
 		/* Version 1.0 – Official Release                     */
 		/******************************************************/
 	bool safe_extensions;
-	bool full_token_loc;       /* error messages specify full token location */
-	bool conversion_functions; /* Create a conversion function for derived datatype */
-	bool nested_comments;      /* Allow the use of nested comments. */
-	bool ref_operator;         /* Allow the use of REFerences (keywords REF_TO, REF, NULL). */
-	bool ref_to_any;           /* Allow the use of REF_TO ANY datatypes - non-standard extension! */
-	const char *includedir;    /* Include directory, where included files will be searched for... */
+	bool full_token_loc;           /* error messages specify full token location */
+	bool conversion_functions;     /* Create a conversion function for derived datatype */
+	bool nested_comments;          /* Allow the use of nested comments. */
+	bool ref_standard_extensions;  /* Allow the use of REFerences (keywords REF_TO, REF, DREF, ^, NULL). */
+	bool ref_nonstand_extensions;  /* Allow the use of non-standard extensions to REF_TO datatypes: REF_TO ANY, and REF_TO in struct elements! */
+	const char *includedir;        /* Include directory, where included files will be searched for... */
 } stage1_2_options_t;